@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2005-2007 by Joris Guisson                              *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005-2007 Joris Guisson <joris.guisson@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "upnpdescriptionparser.h"
 
@@ -25,52 +11,55 @@
 #include <QStringRef>
 #include <QXmlStreamReader>
 
+#include "upnprouter.h"
 #include <util/fileops.h>
 #include <util/log.h>
-#include "upnprouter.h"
 
 using namespace bt;
 
 namespace bt
 {
-
 class XMLContentHandler
 {
     enum Status {
-        TOPLEVEL, ROOT, DEVICE, SERVICE, FIELD, OTHER
+        TOPLEVEL,
+        ROOT,
+        DEVICE,
+        SERVICE,
+        FIELD,
+        OTHER,
     };
 
     QString tmp;
-    UPnPRouter* router;
+    UPnPRouter *router;
     UPnPService curr_service;
     QStack<Status> status_stack;
+
 public:
-    XMLContentHandler(UPnPRouter* router);
+    XMLContentHandler(UPnPRouter *router);
     ~XMLContentHandler();
 
-    bool parse(const QByteArray& data);
+    bool parse(const QByteArray &data);
 
     bool startDocument();
     bool endDocument();
-    bool startElement(const QStringRef& namespaceUri, const QStringRef& localName,
-                      const QStringRef& qName, const QXmlStreamAttributes& atts);
-    bool endElement(const QStringRef& namespaceUri, const QStringRef& localName,
-                    const QStringRef& qName);
-    bool characters(const QStringRef& chars);
+    bool startElement(const QStringRef &namespaceUri, const QStringRef &localName, const QStringRef &qName, const QXmlStreamAttributes &atts);
+    bool endElement(const QStringRef &namespaceUri, const QStringRef &localName, const QStringRef &qName);
+    bool characters(const QStringRef &chars);
 
-    bool interestingDeviceField(const QStringRef& name);
-    bool interestingServiceField(const QStringRef& name);
+    bool interestingDeviceField(const QStringRef &name);
+    bool interestingServiceField(const QStringRef &name);
 };
 
-
 UPnPDescriptionParser::UPnPDescriptionParser()
-{}
-
+{
+}
 
 UPnPDescriptionParser::~UPnPDescriptionParser()
-{}
+{
+}
 
-bool UPnPDescriptionParser::parse(const QString & file, UPnPRouter* router)
+bool UPnPDescriptionParser::parse(const QString &file, UPnPRouter *router)
 {
     QFile fptr(file);
     if (!fptr.open(QIODevice::ReadOnly))
@@ -88,13 +77,12 @@ bool UPnPDescriptionParser::parse(const QString & file, UPnPRouter* router)
     return true;
 }
 
-bool UPnPDescriptionParser::parse(const QByteArray & data, UPnPRouter* router)
+bool UPnPDescriptionParser::parse(const QByteArray &data, UPnPRouter *router)
 {
     XMLContentHandler chandler(router);
 
     const bool ret = chandler.parse(data);
 
-
     if (!ret) {
         Out(SYS_PNP | LOG_IMPORTANT) << "Error parsing XML" << endl;
         return false;
@@ -104,14 +92,16 @@ bool UPnPDescriptionParser::parse(const QByteArray & data, UPnPRouter* router)
 
 /////////////////////////////////////////////////////////////////////////////////
 
-
-XMLContentHandler::XMLContentHandler(UPnPRouter* router) : router(router)
-{}
+XMLContentHandler::XMLContentHandler(UPnPRouter *router)
+    : router(router)
+{
+}
 
 XMLContentHandler::~XMLContentHandler()
-{}
+{
+}
 
-bool XMLContentHandler::parse(const QByteArray& data)
+bool XMLContentHandler::parse(const QByteArray &data)
 {
     QXmlStreamReader reader(data);
 
@@ -132,14 +122,12 @@ bool XMLContentHandler::parse(const QByteArray& data)
             }
             break;
         case QXmlStreamReader::StartElement:
-            if (!startElement(reader.namespaceUri(), reader.name(),
-                              reader.qualifiedName(), reader.attributes())) {
+            if (!startElement(reader.namespaceUri(), reader.name(), reader.qualifiedName(), reader.attributes())) {
                 return false;
             }
             break;
         case QXmlStreamReader::EndElement:
-            if (!endElement(reader.namespaceUri(), reader.name(),
-                            reader.qualifiedName())) {
+            if (!endElement(reader.namespaceUri(), reader.name(), reader.qualifiedName())) {
                 return false;
             }
             break;
@@ -172,21 +160,17 @@ bool XMLContentHandler::endDocument()
     return true;
 }
 
-bool XMLContentHandler::interestingDeviceField(const QStringRef& name)
+bool XMLContentHandler::interestingDeviceField(const QStringRef &name)
 {
-    return name == "friendlyName" || name == "manufacturer" || name == "modelDescription" ||
-           name == "modelName" || name == "modelNumber";
+    return name == "friendlyName" || name == "manufacturer" || name == "modelDescription" || name == "modelName" || name == "modelNumber";
 }
 
-
-bool XMLContentHandler::interestingServiceField(const QStringRef& name)
+bool XMLContentHandler::interestingServiceField(const QStringRef &name)
 {
-    return name == "serviceType" || name == "serviceId" || name == "SCPDURL" ||
-           name == "controlURL" || name == "eventSubURL";
+    return name == "serviceType" || name == "serviceId" || name == "SCPDURL" || name == "controlURL" || name == "eventSubURL";
 }
 
-bool XMLContentHandler::startElement(const QStringRef& namespaceUri, const QStringRef& localName,
-                                     const QStringRef& qName, const QXmlStreamAttributes& atts)
+bool XMLContentHandler::startElement(const QStringRef &namespaceUri, const QStringRef &localName, const QStringRef &qName, const QXmlStreamAttributes &atts)
 {
     Q_UNUSED(namespaceUri)
     Q_UNUSED(qName)
@@ -236,8 +220,7 @@ bool XMLContentHandler::startElement(const QStringRef& namespaceUri, const QStri
     return true;
 }
 
-bool XMLContentHandler::endElement(const QStringRef& namespaceUri, const QStringRef& localName,
-                                   const QStringRef& qName)
+bool XMLContentHandler::endElement(const QStringRef &namespaceUri, const QStringRef &localName, const QStringRef &qName)
 {
     Q_UNUSED(namespaceUri)
     Q_UNUSED(qName)
@@ -271,7 +254,7 @@ bool XMLContentHandler::endElement(const QStringRef& namespaceUri, const QString
     return true;
 }
 
-bool XMLContentHandler::characters(const QStringRef& chars)
+bool XMLContentHandler::characters(const QStringRef &chars)
 {
     tmp.append(chars);
     return true;
